<?php 


if (!class_exists( 'RWMB_Loader' )) {
	return;
}


//	Main
add_filter( 'rwmb_meta_boxes', 'bonza_main_meta_boxes' );
function bonza_main_meta_boxes( $meta_boxes ) {
    
	// Prefix
	$prefix = 'bonza_';
	
	$theme_uri = get_template_directory_uri();

    $meta_boxes[] = array(
        'title'      => esc_html__( 'Main', 'bonza' ),
        'post_types' => array( 'page' ),
        'context' => 'advanced',
        'fields'     => array(
			array(
				'name' => esc_html__( 'Page Layout', 'bonza' ),
				'label_description' => esc_html__( 'Select the layout for this page.', 'bonza' ),
				'id' => $prefix . 'page_layout',
				'type' => 'select',
				'options' => array(
					'' => esc_html__( 'Default', 'bonza' ),
					'full-width' => esc_html__( 'Full-Width', 'bonza' ),
					'boxed' => esc_html__( 'Boxed', 'bonza' ),
				),
			),
			
			array(
				'name' => esc_html__( 'Page Background Image', 'bonza'),
				'label_description' => esc_html__( 'Select a custom background image for your page. Only for Boxed Page Layout.', 'bonza' ),
				'id' => $prefix . 'page_bg',
				'type' => 'background',
			)
        )
    );
    return $meta_boxes;
}


//	Header
add_filter( 'rwmb_meta_boxes', 'bonza_header_meta_boxes' );
function bonza_header_meta_boxes( $meta_boxes ) {
    
	// Prefix
	$prefix = 'bonza_';

    $meta_boxes[] = array(
		'title'      => esc_html__( 'Header', 'bonza' ),
		'post_types' => array( 'page' ),
		'context' => 'advanced',
		'fields'     => array(
			array(
				'name' => esc_html__( 'Header Layout', 'bonza' ),
				'label_description' => esc_html__( 'You can choose between a header full width style menu or a boxed style menu.', 'bonza' ),
				'id' => $prefix . 'header_layout',
				'type' => 'select',
				'options' => array(
					'' => esc_html__( 'Default', 'bonza' ),
					'full_width' => esc_html__( 'Full Width', 'bonza' ),
					'boxed' => esc_html__( 'Boxed', 'bonza' )
				),
				'std' => '',
			),
			array(
				'name' => esc_html__( 'Header Background Style', 'bonza' ),
				'label_description' => esc_html__( 'Select a background style for this header. settings of background color, transparency or settings of gradient will be taken from the Theme Options.', 'bonza' ),
				'id' => $prefix . 'header_page_bg_style',
				'type' => 'select',
				
				'options' => array(
					'' => esc_html__( 'Default', 'bonza' ),
					'gradient' => esc_html__( 'Gradient', 'bonza' ),
					'bgcolor' => esc_html__( 'Background Color', 'bonza' ),
				),
				'std' => '',
			)
		)
	);

    return $meta_boxes;
}


//	Page Title
add_filter( 'rwmb_meta_boxes', 'bonza_pagetitle_meta_boxes' );
function bonza_pagetitle_meta_boxes( $meta_boxes ) {
    
	// Prefix
	$prefix = 'bonza_';

	$visibility_options = array(
		'' => esc_html__( 'Default', 'bonza' ),
		'show' => esc_html__( 'Shown', 'bonza' ),
		'hide' => esc_html__( 'Hidden', 'bonza' ),
	);


    $meta_boxes[] = array(
        'title'      => esc_html__( 'Page Title', 'bonza' ),
        'post_types' => array( 'page' ),
        'context' => 'advanced',
        'fields'     => array(
			array(
				'name' => esc_html__( 'Title', 'bonza' ),
				'label_description' => esc_html__( 'Enable or disable title on this page or post.', 'bonza' ),
				'id' => $prefix . 'pagetitle',
				'type' => 'select',
				'options' => $visibility_options,
				'std' => '',
			),
			array(
				'name' => esc_html__( 'Page Title', 'bonza' ),
				'label_description' => esc_html__( 'Please enter the page title.', 'bonza' ),
				'type' => 'text',
				'id' => $prefix . 'pagetitle_text',
			),
			array(
				'name' => esc_html__( 'Subheading', 'bonza' ),
				'label_description' => esc_html__( 'Enter your page subheading.', 'bonza' ),
				'type' => 'text',
				'id' => $prefix . 'pagetitle_subtext',
			),
			array(
				'name' => esc_html__( 'Page Title Background', 'bonza'),
				'label_description' => esc_html__( 'Select a background styles for your Page Title.', 'bonza' ),
				'id' => $prefix . 'pagetitle_bg',
				'type' => 'background',
			),
			array(
				'name' 		=> esc_html__( 'Parallax Effect', 'bonza' ),
				'label_description' 	=> esc_html__( 'Enable this to the parallax effect for background image.', 'bonza' ),
				'type' 			=> 'select',
				'id' 			=> $prefix . 'pagetitle_bg_image_parallax',
				'options' 		=> array(	
									''		 		=> esc_html__( 'Default', 'bonza' ),
									'disable' 		=> esc_html__( 'Disable', 'bonza' ),
									'enable' 		=> esc_html__( 'Enable', 'bonza' )
								),
				'std' 		=> '',
			),
			array(
				'name' 		=> esc_html__( 'Page Title Text Color', 'bonza' ),
				'label_description' 	=> esc_html__( 'Select a text color.', 'bonza' ),
				'id' 			=> $prefix .'pagetitle_text_color',
				'type' 			=> 'color',
				'std' 		=> '',
			),
			
			array(
				'name' => esc_html__( 'Breadcrumbs', 'bonza' ),
				'label_description' => esc_html__( 'Enable or disable breadcrumbs on this page or post.', 'bonza' ),
				'id' => $prefix . 'breadcrumbs',
				'type' => 'select',
				'options' => $visibility_options,
				'std' => '',
			)
        )
    );

    return $meta_boxes;
}


//	Footer
add_filter( 'rwmb_meta_boxes', 'bonza_footer_meta_boxes' );
function bonza_footer_meta_boxes( $meta_boxes ) {
    
	// Prefix
	$prefix = 'bonza_';

	$visibility_options = array(
		'' => esc_html__( 'Default', 'bonza' ),
		'show' => esc_html__( 'Shown', 'bonza' ),
		'hide' => esc_html__( 'Hidden', 'bonza' ),
	);


    $meta_boxes[] = array(
        'title'      => esc_html__( 'Footer', 'bonza' ),
        'post_types' => array( 'page' ),
        'context' => 'advanced',
        'fields'     => array(
			array(
				'name' => esc_html__( 'Prefooter Area', 'bonza' ),
				'label_description' => esc_html__( 'Show or hide prefooter area.', 'bonza' ),
				'id' => $prefix . 'enable_prefooter',
				'type' => 'select',
				'options' => $visibility_options,
				'std' => '',
			),
			array(
				'name' => esc_html__( 'Footer Area', 'bonza' ),
				'label_description' => esc_html__( 'Show or hide Footer Area.', 'bonza' ),
				'id' => $prefix . 'footer',
				'type' => 'select',
				'options' => $visibility_options,
				'std' => '',
			),
			array(
				'name' => esc_html__( 'Footer Layout', 'bonza' ),
				'id' => $prefix . 'footer_layout',
				'type' => 'select',
				'label_description' => esc_html__( 'You can choose between a full width style or a boxed style footer.', 'bonza' ),
				'options' => array(
					'' => esc_html__( 'Default', 'bonza' ),
					'full_width' => esc_html__( 'Full Width', 'bonza' ),
					'boxed' => esc_html__( 'Boxed', 'bonza' )
				),
				'std' => '',
			)
        )
    );

    return $meta_boxes;
}


//	Blog Post
add_filter( 'rwmb_meta_boxes', 'bonza_blog_meta_boxes' );
function bonza_blog_meta_boxes( $meta_boxes ) {
	
	// Prefix
	$prefix = 'bonza_';

	$meta_boxes[] = array(
		'title'      => esc_html__( 'Post Settings', 'bonza' ),
		'post_types' => array( 'post' ),
		'context' => 'advanced',
		'fields'     => array(
			array(
				'name' => esc_html__( 'Masonry Item Sizing', 'bonza' ),
				'label_description' => esc_html__( 'This will only be used if you choose to display your Blog Posts in the "Metro Style" in element settings', 'bonza' ),
				'id' => $prefix . 'metro',
				'type' => 'select',
				'options' => array(
					'' => esc_html__( 'Default', 'bonza' ),
					'width2' => esc_html__( 'Double Width', 'bonza' ),
					'height2' => esc_html__( 'Double Height', 'bonza' ),
					'wh2' => esc_html__( 'Double Width and Height', 'bonza' ),
				),
				'std' => '',
			),
			array(
				'name' => esc_html__( 'Featured Image Style', 'bonza' ),
				'label_description' => esc_html__( 'Select the style of a single post page. featured image in full screen or standard', 'bonza' ),
				'id' => $prefix . 'post_single_style',
				'type' => 'select',
				'options' => array(
					'' => esc_html__( 'Default', 'bonza' ),
					'fullscreen' => esc_html__( 'Full screen', 'bonza' ),
					'featured_image_hide' => esc_html__( 'Hidden', 'bonza' ),
				),
			),
			
			// Quote Post Format
			array(
				'name' 				=> esc_html__( 'Quote Post Format', 'bonza' ),
				'label_description' => esc_html__( 'Write your quote in this field. Will show only for Quote Post Format.', 'bonza' ),
				'id' 				=> $prefix . 'post_quote_text',
				'type'             	=> 'text',
			),
			array(
				'name' => esc_html__( 'Quote Author', 'bonza' ),
				'label_description' => esc_html__( 'Write your quote author in this field. Will show only for Quote Post Format.', 'bonza' ),
				'id' => $prefix . 'post_quote_author',
				'type' => 'text',
			),
			array(
				'name' => esc_html__( 'Quote Author Position', 'bonza' ),
				'label_description' => esc_html__( 'Write your quote author position in this field. Will show only for Quote Post Format.', 'bonza' ),
				'id' => $prefix . 'post_quote_author_position',
				'type' => 'text',
			),

			// Link Post Format
			array(
				'name' => esc_html__( 'Link', 'bonza' ),
				'label_description' => esc_html__( 'Write your link in this field. Will show only for Link Post Format.', 'bonza' ),
				'id' => $prefix . 'post_link',
				'type'             => 'url',
			),

			// Gallery Post Format
			array(
				'name' 			=> esc_html__( 'Gallery', 'bonza' ),
				'label_description' => esc_html__( 'Select the images that should be upload to this gallery. Will show only for Gallery Post Format.', 'bonza' ),
				'id' 			=> $prefix . 'post_format_gallery_images',
				'type'         	=> 'image_advanced',
				'max_file_uploads' => '',
				'image_size'       => 'thumbnail',
			),

			// Video Post Format
			array(
				'name' => esc_html__( 'Video Embed Code', 'bonza' ),
				'label_description' => esc_html__( 'Insert Youtube or Vimeo embed code. Videos will show only for Video Post Format.', 'bonza' ),
				'id' => $prefix . 'post_video_embed',
				'type' => 'oembed',
				'size'  => 70,
			),
			
			// Audio Post Format
			array(
				'name' => esc_html__( 'Audio Embed Code', 'bonza' ),
				'label_description' => esc_html__( 'Insert audio embed code. Audios will show only for Audio Post Format.', 'bonza' ),
				'id' => $prefix . 'post_audio_embed',
				'type' => 'oembed',
				'size'  => 70,
			)
		)
	);

	return $meta_boxes;
}


//	Portfolio
add_filter( 'rwmb_meta_boxes', 'bonza_portfolio_meta_boxes' );
function bonza_portfolio_meta_boxes( $meta_boxes ) {
	
	// Prefix
	$prefix = 'bonza_';

	$meta_boxes[] = array(
		'title'      => esc_html__( 'Portfolio Settings', 'bonza' ),
		'post_types' => array( 'portfolio' ),
		'context' => 'advanced',
		'fields'     => array(
			array(
				'name' => esc_html__( 'Layout', 'bonza' ),
				'label_description' => esc_html__( 'Select page layout for single portfolio', 'bonza' ),
				'id' => $prefix . 'portfolio_single_layout',
				'type' => 'select',
				'options' => array(
					'full_width' => esc_html__( 'Full width (Description on top, images bottom)', 'bonza' ),
					'half_width' => esc_html__( 'Half width (Description right, images left)', 'bonza' ),
				),
			),
			array(
				'name' => esc_html__( 'Description Box', 'bonza' ),
				'label_description' => esc_html__( 'Show / Hide box with description', 'bonza' ),
				'id' => $prefix . 'portfolio_single_description_box',
				'type' => 'select',
				'options' => array(
					'' => esc_html__( 'Default', 'bonza' ),
					'show' => esc_html__( 'Shown', 'bonza' ),
					'hide' => esc_html__( 'Hidden', 'bonza' ),
				),
			),
			array(
				'name' => esc_html__( 'Additional Fields', 'bonza' ),
				'id' => $prefix . 'portfolio_single_fields',
				'type' => 'fieldset_text',
				'options' => array(
					'title' => 'Title',
					'text' => 'Text',
				),
				'clone' => true,
			),
			array(
				'name' => esc_html__( 'Link', 'bonza' ),
				'label_description' => '',
				'id' => $prefix . 'portfolio_single_link',
				'type' => 'text',
			),
			array(
				'name' => esc_html__( 'Link Name', 'bonza' ),
				'label_description' => '',
				'id' => $prefix . 'portfolio_single_link_name',
				'type' => 'text',
			),
			array(
				'name' => esc_html__( 'Embed Code', 'bonza' ),
				'label_description' => esc_html__( 'Insert your embed/iframe code.', 'bonza' ),
				'id' => $prefix . 'posrtfolio_single_iframe',
				'type' => 'oembed',
				'size'  => 70,
			),
			array(
				'name' => esc_html__( 'Gallery', 'bonza' ),
				'label_description' => esc_html__( 'Select the images that should be upload to this gallery. Will show only for Gallery Post Format.', 'bonza' ),
				'id' => $prefix . 'portfolio_single_gallery',
				'type' => 'image_advanced',
				'max_file_uploads' => '',
				'image_size' => 'thumbnail',
			),
			array(
				'name' => esc_html__( 'Gallery Carousel', 'bonza' ),
				'label_description' => esc_html__( 'Enable this to show images in carousel.', 'bonza' ),
				'id' => $prefix . 'portfolio_single_carousel_enable',
				'type' => 'select',
				'options' => array(
					'enable' => esc_html__( 'Enable', 'bonza' ),
					'disable' => esc_html__( 'Disable', 'bonza' ),
				),
			),
			array(
				'name' => esc_html__( 'Gallery Layout', 'bonza' ),
				'label_description' => esc_html__( 'Enable this to show full width carousel. Only for "Full Width Layout"', 'bonza' ),
				'id' => $prefix . 'portfolio_single_carousel_layout',
				'type' => 'select',
				'options' => array(
					'boxed' => esc_html__( 'Boxed', 'bonza' ),
					'full_width' => esc_html__( 'Full_width', 'bonza' ),
				),
			),
			array(
				'name' => esc_html__( 'Images Position', 'bonza' ),
				'label_description' => esc_html__( 'Enable the option to press all of the images to the left side of the monitor. Only for "Gallery Carousel -> Disable"', 'bonza' ),
				'id' => $prefix . 'portfolio_single_grid_pullleft',
				'type' => 'select',
				'options' => array(
					'disable' => esc_html__( 'Disable', 'bonza' ),
					'enable' => esc_html__( 'Enable', 'bonza' ),
				),
			),
		)
	);
	return $meta_boxes;
}


//	WooCommerce
if ( class_exists( 'woocommerce' ) ) {
	add_filter( 'rwmb_meta_boxes', 'bonza_product_meta_boxes' );
	function bonza_product_meta_boxes( $meta_boxes ) {
		
		// Prefix
		$prefix = 'bonza_';

		$meta_boxes[] = array(
			'title'      => esc_html__( 'Products Settings', 'bonza' ),
			'post_types' => array( 'product' ),
			'context' => 'advanced',
			'fields'     => array(
				array(
					'name' => esc_html__( 'Video URL', 'bonza' ),
					'label_description' => esc_html__( 'Enter URL of Youtube or Vimeo or specific filetypes such as mp4, m4v, webm, ogv, wmv, flv.', 'bonza' ),
					'id' => $prefix . 'product_video_url',
					'type' => 'oembed',
					'size' => 70,
				),
				array(
					'name' => esc_html__( 'Video Thumbnail', 'bonza' ),
					'label_description' => esc_html__( 'Add video thumbnail', 'bonza' ),
					'id' => $prefix . 'product_video_thumbnail',
					'type' => 'single_image',
				),
				array(
					'name' => esc_html__( 'Size Guide Popup Image', 'bonza' ),
					'label_description' => esc_html__( 'Add size guide image', 'bonza' ),
					'id' => $prefix . 'product_size_guide_img',
					'type' => 'single_image',
				)
			)
		);
		return $meta_boxes;
	}
}

?>